@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 Tobias Brunner
+ * Copyright (C) 2007-2020 Tobias Brunner
  * Copyright (C) 2005-2011 Martin Willi
  * Copyright (C) 2005 Jan Hutter
  *
@@ -122,6 +122,12 @@ enum exchange_type_t{
 	 */
 	IKE_SESSION_RESUME = 38,
 
+	/* IKE_INTERMEDIATE (RFC 9242) */
+	IKE_INTERMEDIATE = 43,
+
+	/* IKE_FOLLOWUP_KE (RFC 9370) */
+	IKE_FOLLOWUP_KE = 44,
+
 #ifdef ME
 	/**
 	 * ME_CONNECT
