@@ -81,7 +81,7 @@ METHOD(plugin_t, destroy, void,
 /*
  * see header file
  */
-plugin_t *eap_aka_plugin_create()
+PLUGIN_DEFINE(eap_aka)
 {
 	private_eap_aka_plugin_t *this;
 
