@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 Tobias Brunner
+ * Copyright (C) 2008-2023 Tobias Brunner
  *
  * Copyright (C) secunet Security Networks AG
  *
@@ -40,7 +40,16 @@ typedef union {
 	u_char bytes[KERNEL_NETLINK_BUFSIZE];
 } netlink_buf_t __attribute__((aligned(RTA_ALIGNTO)));
 
+/**
+ * Callback function for netlink events.
+ *
+ * @param user		user data, as passed to constructor
+ * @param hdr		received netlink message
+ */
+typedef void (*netlink_event_cb_t)(void *user, struct nlmsghdr *hdr);
+
 typedef struct netlink_socket_t netlink_socket_t;
+typedef struct netlink_event_socket_t netlink_event_socket_t;
 
 /**
  * Wrapper around a netlink socket.
@@ -80,6 +89,45 @@ struct netlink_socket_t {
 netlink_socket_t *netlink_socket_create(int protocol, enum_name_t *names,
 										bool parallel);
 
+/**
+ * Wrapper around a bound netlink event socket.
+ */
+struct netlink_event_socket_t {
+
+	/**
+	 * Destroy the event socket.
+	 */
+	void (*destroy)(netlink_event_socket_t *this);
+};
+
+/**
+ * Create a netlink_event_socket_t object.
+ *
+ * @param protocol	protocol type (e.g. NETLINK_XFRM or NETLINK_ROUTE)
+ * @param groups	event groups to bind (use nl_group())
+ * @param cb		callback to invoke for each event
+ * @param user		user data passed to callback
+ */
+netlink_event_socket_t *netlink_event_socket_create(int protocol, uint32_t groups,
+													netlink_event_cb_t cb, void *user);
+
+/**
+ * Helper to create bitmask for Netlink multicast groups.
+ *
+ * For groups > 31, setsockopt() with NETLINK_ADD_MEMBERSHIP has to be used,
+ * which is currently not supported by the event socket.
+ */
+static inline uint32_t nl_group(uint32_t group)
+{
+	if (group > 31)
+	{
+		DBG1(DBG_KNL, "netlink multicast group %d currently not supported",
+			 group);
+		return 0;
+	}
+	return group ? (1 << (group - 1)) : 0;
+}
+
 /**
  * Creates an rtattr and adds it to the given netlink message.
  *
