@@ -339,7 +339,7 @@ static SOCKET open_socket(private_socket_win_socket_t *this, int i)
 		.sin6_port = htons(this->ports[i]),
 	};
 	int addrlen = sizeof(addr);
-	BOOL on = TRUE, off = FALSE;
+	BOOL off = FALSE;
 	DWORD dwon = TRUE;
 	SOCKET s;
 
@@ -357,13 +357,6 @@ static SOCKET open_socket(private_socket_win_socket_t *this, int i)
 		closesocket(s);
 		return INVALID_SOCKET;
 	}
-	if (setsockopt(s, SOL_SOCKET, SO_REUSEADDR,
-				   (const char*)&on, sizeof(on)) == SOCKET_ERROR)
-	{
-		DBG1(DBG_NET, "enabling SO_REUSEADDR failed: %d", WSAGetLastError());
-		closesocket(s);
-		return INVALID_SOCKET;
-	}
 	if (bind(s, (const struct sockaddr*)&addr, addrlen) == SOCKET_ERROR)
 	{
 		DBG1(DBG_NET, "unable to bind socket: %d", WSAGetLastError());
