@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2012 Martin Willi
- * Copyright (C) 2012 revosec AG
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -103,7 +104,7 @@ METHOD(plugin_t, destroy, void,
 /*
  * see header file
  */
-plugin_t *unity_plugin_create()
+PLUGIN_DEFINE(unity)
 {
 	private_unity_plugin_t *this;
 
