@@ -47,7 +47,7 @@ METHOD(plugin_t, destroy, void,
 /*
  * see header file
  */
-plugin_t *xauth_generic_plugin_create()
+PLUGIN_DEFINE(xauth_generic)
 {
 	xauth_generic_plugin_t *this;
 
