@@ -97,7 +97,7 @@ struct eap_method_t {
 	 * @param vendor	pointer receiving vendor identifier for type, 0 for none
 	 * @return			type of the EAP method
 	 */
-	eap_type_t (*get_type) (eap_method_t *this, uint32_t *vendor);
+	eap_type_t (*get_type) (eap_method_t *this, pen_t *vendor);
 
 	/**
 	 * Check if this EAP method authenticates the server.
