@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2016 Tobias Brunner
- * HSR Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,14 +25,14 @@
 #ifndef MOCK_DH_H_
 #define MOCK_DH_H_
 
-#include <crypto/diffie_hellman.h>
+#include <crypto/key_exchange.h>
 
 /**
- * Creates a diffie_hellman_t object.
+ * Creates a key_exchange_t object.
  *
- * @param group			Diffie Hellman group, supports MODP_NULL only
+ * @param method		key_exchange method, supports MODP_NULL only
  * @return				created object
  */
-diffie_hellman_t *mock_dh_create(diffie_hellman_group_t group);
+key_exchange_t *mock_dh_create(key_exchange_method_t method);
 
 #endif /** MOCK_DH_H_ @}*/
