@@ -413,7 +413,7 @@ METHOD(imv_agent_t, create_state, TNC_Result,
 {
 	TNC_ConnectionID conn_id;
 	char *tnccs_p = NULL, *tnccs_v = NULL, *t_p = NULL, *t_v = NULL;
-	bool has_long = FALSE, has_excl = FALSE, has_soh = FALSE;
+	bool has_long = FALSE, has_excl = FALSE, has_soh DBG_UNUSED = FALSE;
 	linked_list_t *ar_identities;
 	imv_session_t *session;
 	uint32_t max_msg_len;
