@@ -1,7 +1,8 @@
 /*
  * Copyright (C) 2011 Sansar Choinyambuu
  * Copyright (C) 2014 Andreas Steffen
- * HSR Hochschule fuer Technik Rapperswil
+ *
+ * Copyright (C) secunet Security Networks AG
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -126,7 +127,8 @@ METHOD(pts_file_meas_t, check, bool,
 	enumerator_t *enumerator, *e;
 	entry_t *entry;
 	chunk_t hash;
-	int count_ok = 0, count_not_found = 0, count_differ = 0;
+	int count_ok DBG_UNUSED = 0, count_not_found DBG_UNUSED = 0;
+	int count_differ DBG_UNUSED = 0;
 	status_t status;
 
 	enumerator = this->list->create_enumerator(this->list);
