@@ -81,7 +81,7 @@ METHOD(plugin_t, destroy, void,
 /*
  * see header file
  */
-plugin_t *acert_plugin_create()
+PLUGIN_DEFINE(acert)
 {
 	private_acert_plugin_t *this;
 
