@@ -93,6 +93,8 @@ METHOD(key_exchange_t, get_public_key, bool,
 	return TRUE;
 }
 
+#ifdef TESTABLE_KE
+
 METHOD(key_exchange_t, set_seed, bool,
 	private_diffie_hellman_t *this, chunk_t value, drbg_t *drbg)
 {
@@ -115,6 +117,8 @@ METHOD(key_exchange_t, set_seed, bool,
 	return TRUE;
 }
 
+#endif /* TESTABLE_KE */
+
 METHOD(key_exchange_t, get_shared_secret, bool,
 	private_diffie_hellman_t *this, chunk_t *secret)
 {
@@ -155,12 +159,15 @@ key_exchange_t *botan_x25519_create(key_exchange_method_t ke)
 			.get_shared_secret = _get_shared_secret,
 			.set_public_key = _set_public_key,
 			.get_public_key = _get_public_key,
-			.set_seed = _set_seed,
 			.get_method = _get_method,
 			.destroy = _destroy,
 		},
 	);
 
+#ifdef TESTABLE_KE
+	this->public.set_seed = _set_seed;
+#endif
+
 	if (!botan_get_rng(&rng, RNG_STRONG))
 	{
 		free(this);
