@@ -62,7 +62,7 @@ METHOD(plugin_t, destroy, void,
 /*
  * see header file
  */
-plugin_t *cmac_plugin_create()
+PLUGIN_DEFINE(cmac)
 {
 	private_cmac_plugin_t *this;
 
