@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2008-2019 Tobias Brunner
+ * Copyright (C) 2023 Andreas Steffen
  * Copyright (C) 2005-2008 Martin Willi
  * Copyright (C) 2005 Jan Hutter
  *
@@ -132,7 +133,7 @@ chunk_t *chunk_map(char *path, bool wr);
 /**
  * munmap() a chunk previously mapped with chunk_map().
  *
- * When unmapping a writeable map, the return value should be checked to
+ * When unmapping a writable map, the return value should be checked to
  * ensure changes landed on disk.
  *
  * @param chunk			pointer returned from chunk_map()
@@ -145,7 +146,7 @@ bool chunk_unmap(chunk_t *chunk);
  *
  * @note Writable maps (i.e. created with wr = TRUE) are NOT cleared.
  *
- * When unmapping a writeable map, the return value should be checked to
+ * When unmapping a writable map, the return value should be checked to
  * ensure changes landed on disk.
  *
  * @param chunk         pointer returned from chunk_map()
@@ -213,6 +214,18 @@ chunk_t chunk_from_base64(chunk_t base64, char *buf);
  */
 chunk_t chunk_to_base32(chunk_t chunk, char *buf);
 
+/**
+ * Convert a chunk of data to decimal encoding.
+ *
+ * The resulting string is '\\0' terminated, but the chunk does not include
+ * the '\\0'. If buf is supplied, it must hold at least (chunk.len * 2.41 + 1).
+ *
+ * @param chunk         data to convert to decimal encoding
+ * @param buf           buffer to write to, NULL to malloc
+ * @return              chunk of encoded data
+ */
+chunk_t chunk_to_dec(chunk_t chunk, char *buf);
+
 /**
  * Free contents of a chunk
  */
@@ -401,6 +414,15 @@ void chunk_hash_seed();
  */
 uint32_t chunk_hash(chunk_t chunk);
 
+/**
+ * Same as chunk_hash() but takes a pointer to a chunk. Can be used in
+ * hashtables.
+ *
+ * @param chunk			pointer to chunk to hash
+ * @return				hash value
+ */
+uint32_t chunk_hash_ptr(chunk_t *chunk);
+
 /**
  * Incremental version of chunk_hash. Use this to hash two or more chunks.
  *
