@@ -631,9 +631,9 @@ static void __attribute__ ((constructor))reg()
 		scep, 'S', "scep",
 		"Enroll an X.509 certificate with a SCEP server",
 		{"--url url [--in file] [--dn distinguished-name] [--san subjectAltName]+",
+		 "--cacert-enc file --cacert-sig file [--cacert file]+",
 		 "[--profile profile] [--password password]",
-		 " --cacert-enc file --cacert-sig file [--cacert file]+",
-		 " --cert file --key file] [--cipher aes|des3]",
+		 "[--cert file --key file] [--cipher aes|des3]",
 		 "[--digest sha256|sha384|sha512|sha224|sha1] [--rsa-padding pkcs1|pss]",
 		 "[--interval time] [--maxpolltime time] [--outform der|pem]"},
 		{
@@ -646,9 +646,9 @@ static void __attribute__ ((constructor))reg()
 			{"password",    'p', 1, "challengePassword to include in cert request"},
 			{"cacert-enc",  'e', 1, "CA certificate for encryption"},
 			{"cacert-sig",  's', 1, "CA certificate for signature verification"},
-			{"cacert",      'C', 1, "Additional CA certificates"},
-			{"cert",        'c', 1, "Old certificate about to be renewed"},
-			{"key",         'k', 1, "Old RSA private key about to be replaced"},
+			{"cacert",      'C', 1, "additional CA certificates"},
+			{"cert",        'c', 1, "old certificate about to be renewed"},
+			{"key",         'k', 1, "old RSA private key about to be replaced"},
 			{"cipher",      'E', 1, "encryption cipher, default: aes"},
 			{"digest",      'g', 1, "digest for signature creation, default: sha256"},
 			{"rsa-padding", 'R', 1, "padding for RSA signatures, default: pkcs1"},
